package OpenERP::OOM::Tutorial;

=pod

=head1 NAME

OpenERP::OOM::Tutorial

=head1 DESCRIPTION

=over 4

=item L<OpenERP::OOM::Tutorial::Schema> - Setting up an OpenERP::OOM Schema

=item L<OpenERP::OOM::Tutorial::Searching> - Tips on searching

=back

=head1 COPYRIGHT & LICENSE

Copyright (C) 2012 OpusVL

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

1;

__END__